"""
..
   This file is part of the CoCy program.
   Copyright (C) 2011 Michael N. Lipp
   
   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.
   
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.

.. codeauthor:: mnl
"""
from cocy.providers import BinarySwitch, Manifest

class BinaryLight(BinarySwitch):
    '''
    classdocs
    '''

    manifest = Manifest("Binary light sample light", "A Light")

    def __init__(self):
        super(BinaryLight, self).__init__(self.manifest)




import os
from setuptools import setup

# Utility function to read the README file.
# Used for the long_description.  It's nice, because now 1) we have a top level
# README file and 2) it's easier to type in the README file than to put a raw
# string in below ...
def read(fname):
    return open(os.path.join(os.path.dirname(__file__), fname)).read()

setup(
    name = "cocy",
    version = "0.1.10",
    author = "Michael N. Lipp",
    author_email = "mnl@mnl.de",
    description = ("A components library for UPnP."),
    license = "GPL",
    keywords = "circuits UPnP",
    url = "http://packages.python.org/cocy",
    long_description=read('pypi-overview.rst'),
    data_files=[('', ['pypi-overview.rst'])],
    classifiers=[
        "Development Status :: 3 - Alpha",
        "License :: OSI Approved :: GNU General Public License (GPL)",
    ],
    packages=['cocy',
              'cocy.core',
              'cocy.portlets',
              'cocy.upnp',
              'cocy.upnp.adapters',
              'cocy.soaplib',
              'cocy.soaplib.serializers',
              'cocy.soaplib.test',
              'cocy.soaplib.util',
              'sampleapps',
              'sampleapps.binary_light',
              'sampleapps.media_renderer'],
    package_data={'cocy.portlets': ['templates/*.properties',
                                    'templates/*.pyhtml',
                                    'templates/themes/default/*'],
                  'cocy.upnp': ['services/*.xml',
                                'templates/*']},
   install_requires = ['circuits == 2.1.0', 'Tenjin', 'rbtranslations', 'circuits-bricks'],
)